@@ -5,12 +5,6 @@
 # @Date: 2018-09-22
 # @Filename: platedb.py
 # @License: BSD 3-clause (http://www.opensource.org/licenses/BSD-3-Clause)
-#
-# @Last modified by: José Sánchez-Gallego (gallegoj@uw.edu)
-# @Last modified time: 2018-12-05 15:17:46
-
-
-from __future__ import absolute_import, division, print_function
 
 from peewee import (BigIntegerField, BooleanField, CharField, CompositeKey, DateField,
                     DateTimeField, DeferredThroughModel, FloatField, ForeignKeyField,
@@ -141,8 +135,6 @@ PlateStatusThroughModel = DeferredThroughModel()
 
 class Plate(OperationsDBModel):
 
-    print_fields = ['plate_id']
-
     chunk = TextField(null=True)
     comment = TextField(null=True)
     current_survey_mode = ForeignKeyField(column_name='current_survey_mode_pk',
@@ -198,6 +190,7 @@ class Plate(OperationsDBModel):
     class Meta:
         db_table = 'plate'
         schema = 'platedb'
+        print_fields = ['plate_id']
 
 
 class PluggingStatus(OperationsDBModel):
